#!/bin/bash
# This is a CodeRunner compile script. Compile scripts are used to compile
# code before being run using the run command specified in CodeRunner
# preferences. This script is invoked with the following properties:
#
# Current directory:	The directory of the source file being run
#
# Arguments $1-$n:		User-defined compile flags	
#
# Environment:			$CR_FILENAME	Filename of the source file being run
#						$CR_ENCODING	Encoding code of the source file
#						$CR_TMPDIR		Path of CodeRunner's temporary directory
#
# This script should have the following return values:
# 
# Exit status:			0 on success (CodeRunner will continue and execute run command)
#
# Output (stdout):		On success, one line of text which can be accessed
#						using the $compiler variable in the run command
#
# Output (stderr):		Anything outputted here will be displayed in
#						the CodeRunner console

[ -z "$CR_SUGGESTED_OUTPUT_FILE" ] && CR_SUGGESTED_OUTPUT_FILE="$PWD/${CR_FILENAME%.*}"

out="$(ghc -o "$CR_SUGGESTED_OUTPUT_FILE" "$CR_FILENAME" "${@:1}")"

status=$?
if [ $status -eq 0 ]; then
	if [ ! -x "$CR_SUGGESTED_OUTPUT_FILE" ]; then
		echo $out
		echo -e "\nCodeRunner Warning: Your code can't be run because there is no Main module. Please run the file in your project containing your Main module."
		exit 1
	fi
	echo $CR_SUGGESTED_OUTPUT_FILE
fi
exit $status
